@@ -2,7 +2,17 @@ from .yaml import yaml
 import os
 import sys
 
-def get_source_and_target_languages(src_path, exclude_source=True):
+def get_all_languages(src_path):
+    args = sys.argv[1:]
+
+    site_path = os.path.join(src_path, "site-i18n.yml")
+
+    with open(site_path) as input_file:
+        config = yaml.load(input_file.read(), Loader=yaml.FullLoader)
+
+    return config["languages"].keys()
+
+def get_source_and_target_languages(src_path, context, exclude_source=True):
 
     args = sys.argv[1:]
 
@@ -26,6 +36,6 @@ def get_source_and_target_languages(src_path, exclude_source=True):
                 source_language = args[i+1].split()
                 break
     else:
-        source_language = config['i18n']['source_language']
+        source_language = config['i18n'].get('source_language', {}).get(context, 'en')
 
     return source_language, [tl for tl in target_languages if not tl == source_language or not exclude_source]
\ No newline at end of file
