@@ -17,13 +17,28 @@ class FileCache:
     def read(self):
         if os.path.exists(self.filename):
             with open(self.filename) as input_file:
-                self.tr = yaml.load(input_file.read(), Loader=yaml.BaseLoader)
+                content = input_file.read()
+                if content.strip() == "": # we ignore empty files
+                    self.tr = {}
+                else:
+                    self.tr = yaml.load(content, Loader=yaml.BaseLoader)
         else:
             self.tr = {}
 
     def write(self):
-        with open(self.filename, 'w') as output_file:
-            output_file.write(yaml.dump(self.tr, indent=2, sort_keys=True, width=60))
+        with open(self.filename, 'wb') as output_file:
+            output_file.write(yaml.dump(self.tr, indent=2, sort_keys=True, width=60, allow_unicode=True, encoding="utf-8"))
+
+    def update_hashes(self, source_language):
+        new_tr = {}
+        for hh, items in self.tr.items():
+            lang_item = items.get(source_language)
+            if not lang_item:
+                continue
+            new_hh = hash(lang_item)
+            new_tr[new_hh] = items
+        self.tr = new_tr
+
 
     def get(self, text, language, source_language=None):
         hh = hash(text)
@@ -72,8 +87,8 @@ def translate(text, source_language, target_language, token):
         "preserve_formatting": "0",
         # formality currently doesn't work for Chinese, Spanish and Japanese
         # To do: Regularly check if this is still true...
-        "formality": "more" if target_language not in ['es', 'zh', 'ja'] else "default",
-        "ignore_tags": "ignore,code,tr-ignore",
+        "formality": "more" if target_language not in ['es', 'zh', 'ja', 'en'] else "default",
+        "ignore_tags": "ignore,code,tr-ignore,md-code",
         "tag_handling": "xml",
         })
     if response.status_code != 200:
